@@ -11,6 +11,7 @@
 # ##################################
 
 # Standard library
+import gettext
 import logging
 from os import environ, rename
 from pathlib import Path
@@ -20,18 +21,23 @@ from timeit import default_timer
 import click
 
 # submodules
-from scan_metadata_processor import ElasticSearchManager
-from scan_metadata_processor import MetadataJsonReader, Unzipper
+from scan_metadata_processor import ES_ENABLED, MetadataJsonReader, Unzipper
 from scan_metadata_processor.utils.bouncer import (
     exit_cli_error,
     exit_cli_normal,
     exit_cli_success,
 )
 
+if ES_ENABLED:
+    from scan_metadata_processor.database.elasticsearch import ElasticSearchManager
+
 # #############################################################################
 # ########## Globals ###############
 # ##################################
 
+# localization
+_ = gettext.gettext
+
 # chronometer
 START_TIME = default_timer()
 
@@ -42,6 +48,7 @@ logger = logging.getLogger(__name__)
 # See: https://click.palletsprojects.com/en/7.x/commands/#context-defaults
 CONTEXT_SETTINGS = dict(obj={})
 
+
 # #############################################################################
 # ####### Command-line ############
 # #################################
@@ -89,7 +96,7 @@ def process(cli_context: click.Context):
             "setting ISOGEO_MD_PROCESSOR_DATABASE_TYPE is not correctly set."
         )
 
-    if db_type == "elastic-search":
+    if db_type == "elastic-search" and ES_ENABLED:
         # db connection
         elasticlient = ElasticSearchManager(
             host=environ.get("DATABASE_HOST"),
@@ -108,8 +115,18 @@ def process(cli_context: click.Context):
 
         # store db insertion method
         db_insertion = elasticlient.insert_document
+    elif db_type == "elastic-search" and not ES_ENABLED:
+        exit_cli_error(
+            ModuleNotFoundError(
+                _("Elastic Search package dependency is not available.")
+            )
+        )
     else:
-        raise NotImplementedError
+        exit_cli_error(
+            NotImplementedError(
+                _("This database type '{}' is not implemented yet.".format(db_type))
+            )
+        )
 
     # -- JSON PROCESSING ---------------------------------------------------------------
     # looking for JSON files
