@@ -69,19 +69,19 @@ class Sign(object):
     # -- PROPERTIES --------------------------------------------------------------------
     # error
     @property
-    def error(self) -> int:
-        """Gets the error of this Metadata search.
+    def error(self) -> str:
+        """Gets the error message.
 
-        :return: The error of this Metadata search.
-        :rtype: int
+        :return: error message recorded by the Scan.
+        :rtype: str
         """
         return self._error
 
     @error.setter
-    def error(self, error: int):
-        """Sets the error of this Metadata search.
+    def error(self, error: str):
+        """Sets the error message.
 
-        :param int error: The error of this Metadata search.
+        :param str error: error message recorded by the Scan.
         """
 
         self._error = error
